INSERT/pymysql - Criterion.rs

## INSERT/pymysql

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0467974 | 0.0484461 | 0.0466981
Mean | 6.5072 ms | 6.6132 ms | 6.7226 ms
Std. Dev. | 482.16 µs | 553.95 µs | 617.46 µs
Median | 6.4016 ms | 6.4826 ms | 6.6956 ms
MAD | 443.68 µs | 564.71 µs | 732.56 µs

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.